Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(108)

Unified Diff: tools/testing/dart/test_runner.dart

Issue 12776004: Add support for the new analyzer to the testing scripts (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/testing/dart/test_runner.dart
===================================================================
--- tools/testing/dart/test_runner.dart (revision 19852)
+++ tools/testing/dart/test_runner.dart (working copy)
@@ -530,7 +530,7 @@
stderr,
time,
compilationSkipped);
- } else if (testCase.configuration['compiler'] == 'dartc') {
+ } else if (testCase.configuration['analyzer']) {
return new AnalysisCommandOutputImpl(testCase,
kustermann 2013/03/12 17:55:23 Is the output of the new analyzer in the same form
ricow1 2013/03/12 18:06:06 Yes
command,
exitCode,
@@ -1204,7 +1204,9 @@
} else if (line.startsWith('>>> BATCH')) {
// ignore
} else if (line.startsWith('>>> ')) {
- throw new Exception('Unexpected command from dartc batch runner.');
+ throw new Exception(
+ 'Unexpected command from ${testCase.configuration['compiler']} '
+ 'batch runner.');
} else {
buffer.addAll(encodeUtf8(line));
buffer.addAll("\n".charCodes);
@@ -1621,15 +1623,17 @@
_progress.start(test);
// Dartc and browser test commands can be run by a [BatchRunnerProcess]
var nextCommandIndex = test.commandOutputs.keys.length;
var numberOfCommands = test.commands.length;
- var useBatchRunnerForDartc = test.configuration['compiler'] == 'dartc' &&
- test.displayName != 'dartc/junit_tests';
+
+ var useBatchRunnerForAnalyzer =
+ test.configuration['analyzer'] &&
kustermann 2013/03/12 17:55:23 Indentation is strange.
ricow1 2013/03/12 18:06:06 Done.
+ test.displayName != 'dartc/junit_tests';
var isWebdriverCommand = nextCommandIndex == (numberOfCommands - 1) &&
test.usesWebDriver &&
!test.configuration['noBatch'];
- if (useBatchRunnerForDartc || isWebdriverCommand) {
+ if (useBatchRunnerForAnalyzer || isWebdriverCommand) {
TestCaseEvent oldCallback = test.completedHandler;
void testCompleted(TestCase test_arg) {
_numProcesses--;
@@ -1621,15 +1623,17 @@
_progress.start(test);
- // Dartc and browser test commands can be run by a [BatchRunnerProcess]
+ // Analyzer and browser test commands can be run by a [BatchRunnerProcess]
var nextCommandIndex = test.commandOutputs.keys.length;
var numberOfCommands = test.commands.length;

Powered by Google App Engine
This is Rietveld 408576698